! File power.mod
!
! 
MODEL POWER
!
!
!       Definerer tabeller for indeksverdier og reservefaktor
TABLES
!
 DIMM(2)        ! Inneh. ant. perioderog ant. typer generatorer
 RESERV(1)      ! Inneh. faktor for ndvendig reserve
!
!
!       Leser indeksverdier og reservefaktor fra fil
DISKDATA
!
 DIMM(1)        = power.dim
 RESERV(1)      = power.res
!
LET     PMAX    = DIMM(1)       ! antall perioder
LET     TMAX    = DIMM(2)       ! antall generatortyper
LET     RESERVE = RESERV(1)     ! faktor for ndvendig reserve
!
!
!       Definerer tabeller for indeksavhengige verdier
TABLES
!
 PINFO(PMAX,2)          ! Inneh. periodenes lengde og last
!
 GENINFO(TMAX,6)        ! Inneh. data for generatortypene
!
!
!       Leser inn indeksavhengige verdier
DISKDATA
!
 PINFO(1,1)     = power.per
 GENINFO(1,1)   = power.gen
!
!
!       Legger informasjonen inn i endimensjonale tabeller
ASSIGN
!
 TIMER(p=1:PMAX)   = PINFO(p,1)         ! antall timer i periode p
 LAST(p=1:PMAX)    = PINFO(p,2)         ! ettersprsel i periode p
!
 GENMIN(t=1:TMAX)  = GENINFO(t,1)       ! min.prod for generator av type t
 GENMAX(t=1:TMAX)  = GENINFO(t,2)       ! maks.prod type t
 MINKOST(t=1:TMAX) = GENINFO(t,3)       ! kost pr time ved min. prod.
 TIMKOST(t=1:TMAX) = GENINFO(t,4)       ! ekstra kost pr time pr MW over min.
 STARTK(t=1:TMAX)  = GENINFO(t,5)       ! startkost for generator av type t
 GENANT(t=1:TMAX)  = GENINFO(t,6)       ! ant. tilgjengelige gen. av type t
!
!
!
VARIABLES
!
 n(t=1:TMAX,p=1:PMAX)           ! antall generatorer av type t som er
!                               ! i drift i periode p
!
 s(t=1:TMAX,p=1:PMAX)           ! antall generatorer av type t som startes 
!                               ! opp i periode p
!
 prod(t=1:TMAX,p=1:PMAX)        ! totalproduksjon for generatorer
!                               ! av type t i periode p
!
!
!
CONSTRAINTS
!
!       Ml: minimerer totale kostnader
!
 TOTKOST: &
    SUM(t=1:TMAX,p=1:PMAX) (TIMKOST(t) * TIMER(p)) * prod(t,p)   &
  + SUM(t=1:TMAX,p=1:PMAX) (MINKOST(t)                           &
  - TIMKOST(t) * GENMIN(t)) * TIMER(p) * n(t,p)                  &
  + SUM(t=1:TMAX,p=1:PMAX) STARTK(t) * s(t,p)                    $
!
!
!
!       Ettersprselen m dekkes
!
 DEKNING(p=1:PMAX):&
      SUM(t=1:TMAX) prod(t,p) - LAST(p)         = 0
!
!
!       Generatorprod. m befinne seg i lovlig omrde
!
 MINPROD(t=1:TMAX,p=1:PMAX):&
      GENMIN(t) * n(t,p) - prod(t,p)            < 0
!
 MAXPROD(t=1:TMAX,p=1:PMAX):&
      prod(t,p) - GENMAX(t) * n(t,p)            < 0
!
!
!        Tilstrekkelig reservekapasitet
!
 RESKAP(p=1:PMAX):&
      RESERVE * LAST(p) - SUM(t=1:TMAX) GENMAX(t) * n(t,p)      < 0
!
!
!       Antall generatorer startet i periode p er gitt ved diff. mellom   
!       antall gen. som gr i denne perioden og de som gikk i den forrige.
!       M bruke ">" for  unng negative s(t,p)
!
 START(t=1:TMAX,p=2:PMAX):&
      n(t,p) - n(t,p-1) - s(t,p)        < 0     ! alle p utenom den frste
!
 STARTF(t=1:TMAX):&
      n(t,1) - n(t,PMAX) - s(t,1)       < 0     ! frste periode
!
!
!
!
BOUNDS
!
!
!       s er ogs heltallsvariabel    
!    
 s(t=1:TMAX,p=1:PMAX) .UI. GENANT(t)
!
!       Kan ikke overskride antall tilgjengelige generatorer
!
 n(t=1:TMAX,p=1:PMAX) .UI. GENANT(t)
!
GENERATE
!
